/* eslint-disable react/jsx-props-no-spreading */
import React, { FC, useEffect, useState } from 'react';
import TextField from '@material-ui/core/TextField';
import Autocomplete from '@material-ui/lab/Autocomplete';
import { getSeniorList } from 'api/getSeniorList';
import { ResponseProps } from 'api/ResponseProps';
import { getSeniorListByCard } from 'api/getSeniorListByCard';

type SeniorSearchProps = {
  senior: ResponseProps | null;
  setSenior: React.Dispatch<React.SetStateAction<ResponseProps | null>>;
};

export const SeniorSearch: FC<SeniorSearchProps> = ({
  senior,
  setSenior,
}: SeniorSearchProps) => {
  const [seniors, setSeniors] = useState<ResponseProps[]>([]);
  const [query, setQuery] = useState<string>('');

  useEffect(() => {
    const MIN_SEARCH_LENGTH = 4;
    const cardNumber = Number(query);
    if (Number.isNaN(cardNumber)) {
      if (query.length >= MIN_SEARCH_LENGTH && senior == null) {
        getSeniorList(query).then((list) => {
          setSeniors([...seniors, ...list]);
        });
      }
    } else {
      getSeniorListByCard(cardNumber).then((list) => {
        setSeniors([...seniors, ...list]);
      });
    }
  }, [query]);

  const handleChange = (newValue: string): void => {
    setQuery(newValue);
  };

  return (
    <Autocomplete
      value={senior}
      id="senior-searcher"
      onInputChange={(_, newValue) => handleChange(newValue)}
      onChange={(_, val) => {
        setSenior(val);
      }}
      options={seniors}
      getOptionSelected={(option, val) => option.id === val.id}
      getOptionLabel={(option) => option.user.lastName}
      renderOption={(option) => (
        <>
          {option.user.firstName} {option.user.lastName} {option.user.username}{' '}
          {option.memberCardNumber}
        </>
      )}
      renderInput={(params) => (
        <TextField
          {...params}
          label="Search a senior"
          variant="outlined"
          InputProps={{
            ...params.InputProps,
          }}
        />
      )}
    />
  );
};
